local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	login_verify_url = "cls.xxqt.huolug.com/aam/login_verify.php",
	create_order_url = "cls.xxqt.huolug.com/aam/create_order.php",

	uid = "",
}

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "aam"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "aam_" .. self.uid
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:OnClickBackLogin()
	Log("OnClickBtnLogin, logout")
	agent_helper:Logout()
end

function AgentAdapter:LoginCallback(result)
	local json_obj = cjson.decode(result)

	if nil == json_obj or nil == json_obj.amigoToken or nil == json_obj.playerId then return end
	self.uid = json_obj.playerId
	self.login_callback(self:GetPlatName(), json_obj.amigoToken)
	return false
end

function AgentAdapter:LogoutCallback(result)
	Log("AgentAdapter:LogoutCallback")
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:UIEventCallback(event)
	if "open" == event then
		--self:ShowFloatButton()
	elseif "close" == event then
		--self:ShowFloatButton()
	end
	return true
end

function AgentAdapter:ShowFloatButton()
	agent_helper:ShowFloatButton(70, 30, true)
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end

	self:CreateOrder(server_id, amount)
end

function AgentAdapter:CreateOrder(server_id, amount)
	local create_order_callback = function(url, arg, data, size)
		Log("create order callback" .. data)
		if size <= 0 then
			Log("create_order_callback, fail:size<=0")
			return
		end

		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret then
			SysMsgCtrl.Instance:ErrorRemind("创建订单失败:" .. ret_t.out_order_no, true)
			Log("create_order_callback, fail")
			return
		end

		local param_obj = {}
		param_obj.order = ret_t.out_order_no
		param_obj.time = ret_t.submit_time
		agent_helper:Pay(cjson.encode(param_obj), nil)
	end

	local order = server_id .. "_" .. self.uid .. "_" .. os.time()
	local real_url = string.format("%s?order=%s&money=%s&uid=%s", self.create_order_url, order, amount, self.uid)
	Log("start Create order" .. real_url)
	HttpClient:Request(real_url, "", create_order_callback)
end

agent_helper:SetLogoutCallback(LUA_CALLBACK(AgentAdapter, AgentAdapter.LogoutCallback))
agent_helper:SetUIEventCallback(LUA_CALLBACK(AgentAdapter, AgentAdapter.UIEventCallback))
